# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import definitions_pb2 as definitions__pb2
from . import peers_pb2 as peers__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='spaces.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cspaces.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x0bpeers.proto\x1a\x15media_and_files.proto\x1a\x15scalapb/scalapb.proto\"\xef\x03\n\x05Space\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x07general\x18\x03 \x01(\x0b\x32\x15.dialog.Space.GeneralH\x00\x12&\n\x06public\x18\x04 \x01(\x0b\x32\x14.dialog.Space.PublicH\x00\x12(\n\x07private\x18\x05 \x01(\x0b\x32\x15.dialog.Space.PrivateH\x00\x12\r\n\x05title\x18\x06 \x01(\t\x12+\n\x05\x61\x62out\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1e\n\x06\x61vatar\x18\x08 \x01(\x0b\x32\x0e.dialog.Avatar\x12.\n\ndeleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x05\x63lock\x18\n \x01(\x0b\x32\x11.dialog.DataClock\x1a\t\n\x07General\x1a\x32\n\x06Public\x12\x15\n\rowner_user_id\x18\x01 \x01(\x05\x12\x11\n\tshortname\x18\x02 \x01(\t\x1a \n\x07Private\x12\x15\n\rowner_user_id\x18\x01 \x01(\x05\x42\x0c\n\nspace_type\"\xf4\x01\n\x0bSpaceMember\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12.\n\ninvited_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tjoined_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x05\x63lock\x18\x06 \x01(\x0b\x32\x11.dialog.DataClock\"3\n\x13UpdateSpaceModified\x12\x1c\n\x05space\x18\x01 \x01(\x0b\x32\r.dialog.Space\"@\n\x19UpdateSpaceMemberModified\x12#\n\x06member\x18\x01 \x01(\x0b\x32\x13.dialog.SpaceMember\"\xd3\x01\n\x12RequestCreateSpace\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12/\n\tshortname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x61\x62out\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1e\n\x06\x61vatar\x18\x05 \x01(\x0b\x32\x0e.dialog.Avatar:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"L\n\rResponseSpace\x12\x1c\n\x05space\x18\x01 \x01(\x0b\x32\r.dialog.Space:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"~\n\x13ResponseSpaceMember\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12#\n\x06member\x18\x02 \x01(\x0b\x32\x13.dialog.SpaceMember:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"s\n\x12RequestDeleteSpace\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12 \n\x05\x63lock\x18\x02 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"1\n\x11RequestLoadSpaces:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"{\n\x12ResponseLoadSpaces\x12\x1c\n\x05space\x18\x01 \x03(\x0b\x32\r.dialog.Space\x12(\n\x0bowner_peers\x18\x02 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x80\x01\n\x19RequestStreamSpaceMembers\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12 \n\x05\x63lock\x18\x02 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"]\n\x13SpaceMemberWithPeer\x12#\n\x06member\x18\x01 \x01(\x0b\x32\x13.dialog.SpaceMember\x12!\n\x04peer\x18\x02 \x01(\x0b\x32\x13.dialog.UserOutPeer\"\x7f\n\x0fRequestSetTitle\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\r\n\x05title\x18\x02 \x01(\t\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa5\x01\n\x13RequestSetShortname\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12/\n\tshortname\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9d\x01\n\x0fRequestSetAbout\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12+\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9e\x01\n\x10RequestSetAvatar\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12+\n\rfile_location\x18\x02 \x01(\x0b\x32\x14.dialog.FileLocation\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x84\x01\n\x12RequestSpaceInvite\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x82\x01\n\x10RequestSpaceKick\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x83\x01\n\x11RequestSpaceLeave\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"W\n\x18RequestGetSpaceInviteUrl\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"K\n\x16ResponseSpaceInviteUrl\x12\x12\n\ninvite_url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"Z\n\x1bRequestRevokeSpaceInviteUrl\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest2\xb2\x07\n\x06Spaces\x12\x42\n\x0b\x43reateSpace\x12\x1a.dialog.RequestCreateSpace\x1a\x15.dialog.ResponseSpace\"\x00\x12\x42\n\x0b\x44\x65leteSpace\x12\x1a.dialog.RequestDeleteSpace\x1a\x15.dialog.ResponseSpace\"\x00\x12<\n\x08SetTitle\x12\x17.dialog.RequestSetTitle\x1a\x15.dialog.ResponseSpace\"\x00\x12\x44\n\x0cSetShortname\x12\x1b.dialog.RequestSetShortname\x1a\x15.dialog.ResponseSpace\"\x00\x12<\n\x08SetAbout\x12\x17.dialog.RequestSetAbout\x1a\x15.dialog.ResponseSpace\"\x00\x12>\n\tSetAvatar\x12\x18.dialog.RequestSetAvatar\x1a\x15.dialog.ResponseSpace\"\x00\x12\x45\n\nLoadSpaces\x12\x19.dialog.RequestLoadSpaces\x1a\x1a.dialog.ResponseLoadSpaces\"\x00\x12V\n\x10LoadSpaceMembers\x12!.dialog.RequestStreamSpaceMembers\x1a\x1b.dialog.SpaceMemberWithPeer\"\x00\x30\x01\x12\x43\n\x06Invite\x12\x1a.dialog.RequestSpaceInvite\x1a\x1b.dialog.ResponseSpaceMember\"\x00\x12?\n\x04Kick\x12\x18.dialog.RequestSpaceKick\x1a\x1b.dialog.ResponseSpaceMember\"\x00\x12\x41\n\x05Leave\x12\x19.dialog.RequestSpaceLeave\x1a\x1b.dialog.ResponseSpaceMember\"\x00\x12W\n\x11GetSpaceInviteUrl\x12 .dialog.RequestGetSpaceInviteUrl\x1a\x1e.dialog.ResponseSpaceInviteUrl\"\x00\x12]\n\x14RevokeSpaceInviteUrl\x12#.dialog.RequestRevokeSpaceInviteUrl\x1a\x1e.dialog.ResponseSpaceInviteUrl\"\x00\x42\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_SPACE_GENERAL = _descriptor.Descriptor(
  name='General',
  full_name='dialog.Space.General',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=563,
)

_SPACE_PUBLIC = _descriptor.Descriptor(
  name='Public',
  full_name='dialog.Space.Public',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='dialog.Space.Public.owner_user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.Space.Public.shortname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=615,
)

_SPACE_PRIVATE = _descriptor.Descriptor(
  name='Private',
  full_name='dialog.Space.Private',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='dialog.Space.Private.owner_user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=649,
)

_SPACE = _descriptor.Descriptor(
  name='Space',
  full_name='dialog.Space',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Space.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='dialog.Space.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='general', full_name='dialog.Space.general', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='dialog.Space.public', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private', full_name='dialog.Space.private', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.Space.title', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.Space.about', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.Space.avatar', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='dialog.Space.deleted_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.Space.clock', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPACE_GENERAL, _SPACE_PUBLIC, _SPACE_PRIVATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='space_type', full_name='dialog.Space.space_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=168,
  serialized_end=663,
)


_SPACEMEMBER = _descriptor.Descriptor(
  name='SpaceMember',
  full_name='dialog.SpaceMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.SpaceMember.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.SpaceMember.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invited_at', full_name='dialog.SpaceMember.invited_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joined_at', full_name='dialog.SpaceMember.joined_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='dialog.SpaceMember.deleted_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.SpaceMember.clock', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=910,
)


_UPDATESPACEMODIFIED = _descriptor.Descriptor(
  name='UpdateSpaceModified',
  full_name='dialog.UpdateSpaceModified',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='dialog.UpdateSpaceModified.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=963,
)


_UPDATESPACEMEMBERMODIFIED = _descriptor.Descriptor(
  name='UpdateSpaceMemberModified',
  full_name='dialog.UpdateSpaceMemberModified',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.UpdateSpaceMemberModified.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1029,
)


_REQUESTCREATESPACE = _descriptor.Descriptor(
  name='RequestCreateSpace',
  full_name='dialog.RequestCreateSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='dialog.RequestCreateSpace.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestCreateSpace.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestCreateSpace.shortname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestCreateSpace.about', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.RequestCreateSpace.avatar', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1032,
  serialized_end=1243,
)


_RESPONSESPACE = _descriptor.Descriptor(
  name='ResponseSpace',
  full_name='dialog.ResponseSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='dialog.ResponseSpace.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1321,
)


_RESPONSESPACEMEMBER = _descriptor.Descriptor(
  name='ResponseSpaceMember',
  full_name='dialog.ResponseSpaceMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.ResponseSpaceMember.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.ResponseSpaceMember.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1449,
)


_REQUESTDELETESPACE = _descriptor.Descriptor(
  name='RequestDeleteSpace',
  full_name='dialog.RequestDeleteSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestDeleteSpace.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestDeleteSpace.clock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1451,
  serialized_end=1566,
)


_REQUESTLOADSPACES = _descriptor.Descriptor(
  name='RequestLoadSpaces',
  full_name='dialog.RequestLoadSpaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1617,
)


_RESPONSELOADSPACES = _descriptor.Descriptor(
  name='ResponseLoadSpaces',
  full_name='dialog.ResponseLoadSpaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='dialog.ResponseLoadSpaces.space', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_peers', full_name='dialog.ResponseLoadSpaces.owner_peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1742,
)


_REQUESTSTREAMSPACEMEMBERS = _descriptor.Descriptor(
  name='RequestStreamSpaceMembers',
  full_name='dialog.RequestStreamSpaceMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.RequestStreamSpaceMembers.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestStreamSpaceMembers.clock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1745,
  serialized_end=1873,
)


_SPACEMEMBERWITHPEER = _descriptor.Descriptor(
  name='SpaceMemberWithPeer',
  full_name='dialog.SpaceMemberWithPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.SpaceMemberWithPeer.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.SpaceMemberWithPeer.peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1968,
)


_REQUESTSETTITLE = _descriptor.Descriptor(
  name='RequestSetTitle',
  full_name='dialog.RequestSetTitle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetTitle.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestSetTitle.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetTitle.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1970,
  serialized_end=2097,
)


_REQUESTSETSHORTNAME = _descriptor.Descriptor(
  name='RequestSetShortname',
  full_name='dialog.RequestSetShortname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetShortname.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestSetShortname.shortname', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetShortname.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2265,
)


_REQUESTSETABOUT = _descriptor.Descriptor(
  name='RequestSetAbout',
  full_name='dialog.RequestSetAbout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetAbout.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestSetAbout.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetAbout.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2425,
)


_REQUESTSETAVATAR = _descriptor.Descriptor(
  name='RequestSetAvatar',
  full_name='dialog.RequestSetAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetAvatar.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.RequestSetAvatar.file_location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetAvatar.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2428,
  serialized_end=2586,
)


_REQUESTSPACEINVITE = _descriptor.Descriptor(
  name='RequestSpaceInvite',
  full_name='dialog.RequestSpaceInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSpaceInvite.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.RequestSpaceInvite.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSpaceInvite.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2589,
  serialized_end=2721,
)


_REQUESTSPACEKICK = _descriptor.Descriptor(
  name='RequestSpaceKick',
  full_name='dialog.RequestSpaceKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSpaceKick.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.RequestSpaceKick.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSpaceKick.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2724,
  serialized_end=2854,
)


_REQUESTSPACELEAVE = _descriptor.Descriptor(
  name='RequestSpaceLeave',
  full_name='dialog.RequestSpaceLeave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSpaceLeave.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.RequestSpaceLeave.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSpaceLeave.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2857,
  serialized_end=2988,
)


_REQUESTGETSPACEINVITEURL = _descriptor.Descriptor(
  name='RequestGetSpaceInviteUrl',
  full_name='dialog.RequestGetSpaceInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestGetSpaceInviteUrl.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3077,
)


_RESPONSESPACEINVITEURL = _descriptor.Descriptor(
  name='ResponseSpaceInviteUrl',
  full_name='dialog.ResponseSpaceInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_url', full_name='dialog.ResponseSpaceInviteUrl.invite_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3079,
  serialized_end=3154,
)


_REQUESTREVOKESPACEINVITEURL = _descriptor.Descriptor(
  name='RequestRevokeSpaceInviteUrl',
  full_name='dialog.RequestRevokeSpaceInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestRevokeSpaceInviteUrl.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3156,
  serialized_end=3246,
)

_SPACE_GENERAL.containing_type = _SPACE
_SPACE_PUBLIC.containing_type = _SPACE
_SPACE_PRIVATE.containing_type = _SPACE
_SPACE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_SPACE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACE.fields_by_name['general'].message_type = _SPACE_GENERAL
_SPACE.fields_by_name['public'].message_type = _SPACE_PUBLIC
_SPACE.fields_by_name['private'].message_type = _SPACE_PRIVATE
_SPACE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SPACE.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_SPACE.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_SPACE.oneofs_by_name['space_type'].fields.append(
  _SPACE.fields_by_name['general'])
_SPACE.fields_by_name['general'].containing_oneof = _SPACE.oneofs_by_name['space_type']
_SPACE.oneofs_by_name['space_type'].fields.append(
  _SPACE.fields_by_name['public'])
_SPACE.fields_by_name['public'].containing_oneof = _SPACE.oneofs_by_name['space_type']
_SPACE.oneofs_by_name['space_type'].fields.append(
  _SPACE.fields_by_name['private'])
_SPACE.fields_by_name['private'].containing_oneof = _SPACE.oneofs_by_name['space_type']
_SPACEMEMBER.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_SPACEMEMBER.fields_by_name['invited_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACEMEMBER.fields_by_name['joined_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACEMEMBER.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACEMEMBER.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_UPDATESPACEMODIFIED.fields_by_name['space'].message_type = _SPACE
_UPDATESPACEMEMBERMODIFIED.fields_by_name['member'].message_type = _SPACEMEMBER
_REQUESTCREATESPACE.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTCREATESPACE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTCREATESPACE.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_RESPONSESPACE.fields_by_name['space'].message_type = _SPACE
_RESPONSESPACEMEMBER.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_RESPONSESPACEMEMBER.fields_by_name['member'].message_type = _SPACEMEMBER
_REQUESTDELETESPACE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTDELETESPACE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_RESPONSELOADSPACES.fields_by_name['space'].message_type = _SPACE
_RESPONSELOADSPACES.fields_by_name['owner_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTSTREAMSPACEMEMBERS.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSTREAMSPACEMEMBERS.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_SPACEMEMBERWITHPEER.fields_by_name['member'].message_type = _SPACEMEMBER
_SPACEMEMBERWITHPEER.fields_by_name['peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTSETTITLE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETTITLE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSETSHORTNAME.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETSHORTNAME.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSETSHORTNAME.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSETABOUT.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETABOUT.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSETABOUT.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSETAVATAR.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETAVATAR.fields_by_name['file_location'].message_type = media__and__files__pb2._FILELOCATION
_REQUESTSETAVATAR.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSPACEINVITE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSPACEINVITE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSPACEKICK.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSPACEKICK.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSPACELEAVE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSPACELEAVE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTGETSPACEINVITEURL.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTREVOKESPACEINVITEURL.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
DESCRIPTOR.message_types_by_name['Space'] = _SPACE
DESCRIPTOR.message_types_by_name['SpaceMember'] = _SPACEMEMBER
DESCRIPTOR.message_types_by_name['UpdateSpaceModified'] = _UPDATESPACEMODIFIED
DESCRIPTOR.message_types_by_name['UpdateSpaceMemberModified'] = _UPDATESPACEMEMBERMODIFIED
DESCRIPTOR.message_types_by_name['RequestCreateSpace'] = _REQUESTCREATESPACE
DESCRIPTOR.message_types_by_name['ResponseSpace'] = _RESPONSESPACE
DESCRIPTOR.message_types_by_name['ResponseSpaceMember'] = _RESPONSESPACEMEMBER
DESCRIPTOR.message_types_by_name['RequestDeleteSpace'] = _REQUESTDELETESPACE
DESCRIPTOR.message_types_by_name['RequestLoadSpaces'] = _REQUESTLOADSPACES
DESCRIPTOR.message_types_by_name['ResponseLoadSpaces'] = _RESPONSELOADSPACES
DESCRIPTOR.message_types_by_name['RequestStreamSpaceMembers'] = _REQUESTSTREAMSPACEMEMBERS
DESCRIPTOR.message_types_by_name['SpaceMemberWithPeer'] = _SPACEMEMBERWITHPEER
DESCRIPTOR.message_types_by_name['RequestSetTitle'] = _REQUESTSETTITLE
DESCRIPTOR.message_types_by_name['RequestSetShortname'] = _REQUESTSETSHORTNAME
DESCRIPTOR.message_types_by_name['RequestSetAbout'] = _REQUESTSETABOUT
DESCRIPTOR.message_types_by_name['RequestSetAvatar'] = _REQUESTSETAVATAR
DESCRIPTOR.message_types_by_name['RequestSpaceInvite'] = _REQUESTSPACEINVITE
DESCRIPTOR.message_types_by_name['RequestSpaceKick'] = _REQUESTSPACEKICK
DESCRIPTOR.message_types_by_name['RequestSpaceLeave'] = _REQUESTSPACELEAVE
DESCRIPTOR.message_types_by_name['RequestGetSpaceInviteUrl'] = _REQUESTGETSPACEINVITEURL
DESCRIPTOR.message_types_by_name['ResponseSpaceInviteUrl'] = _RESPONSESPACEINVITEURL
DESCRIPTOR.message_types_by_name['RequestRevokeSpaceInviteUrl'] = _REQUESTREVOKESPACEINVITEURL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Space = _reflection.GeneratedProtocolMessageType('Space', (_message.Message,), {

  'General' : _reflection.GeneratedProtocolMessageType('General', (_message.Message,), {
    'DESCRIPTOR' : _SPACE_GENERAL,
    '__module__' : 'spaces_pb2'
    # @@protoc_insertion_point(class_scope:dialog.Space.General)
    })
  ,

  'Public' : _reflection.GeneratedProtocolMessageType('Public', (_message.Message,), {
    'DESCRIPTOR' : _SPACE_PUBLIC,
    '__module__' : 'spaces_pb2'
    # @@protoc_insertion_point(class_scope:dialog.Space.Public)
    })
  ,

  'Private' : _reflection.GeneratedProtocolMessageType('Private', (_message.Message,), {
    'DESCRIPTOR' : _SPACE_PRIVATE,
    '__module__' : 'spaces_pb2'
    # @@protoc_insertion_point(class_scope:dialog.Space.Private)
    })
  ,
  'DESCRIPTOR' : _SPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Space)
  })
_sym_db.RegisterMessage(Space)
_sym_db.RegisterMessage(Space.General)
_sym_db.RegisterMessage(Space.Public)
_sym_db.RegisterMessage(Space.Private)

SpaceMember = _reflection.GeneratedProtocolMessageType('SpaceMember', (_message.Message,), {
  'DESCRIPTOR' : _SPACEMEMBER,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SpaceMember)
  })
_sym_db.RegisterMessage(SpaceMember)

UpdateSpaceModified = _reflection.GeneratedProtocolMessageType('UpdateSpaceModified', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEMODIFIED,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateSpaceModified)
  })
_sym_db.RegisterMessage(UpdateSpaceModified)

UpdateSpaceMemberModified = _reflection.GeneratedProtocolMessageType('UpdateSpaceMemberModified', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEMEMBERMODIFIED,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateSpaceMemberModified)
  })
_sym_db.RegisterMessage(UpdateSpaceMemberModified)

RequestCreateSpace = _reflection.GeneratedProtocolMessageType('RequestCreateSpace', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCREATESPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCreateSpace)
  })
_sym_db.RegisterMessage(RequestCreateSpace)

ResponseSpace = _reflection.GeneratedProtocolMessageType('ResponseSpace', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSpace)
  })
_sym_db.RegisterMessage(ResponseSpace)

ResponseSpaceMember = _reflection.GeneratedProtocolMessageType('ResponseSpaceMember', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESPACEMEMBER,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSpaceMember)
  })
_sym_db.RegisterMessage(ResponseSpaceMember)

RequestDeleteSpace = _reflection.GeneratedProtocolMessageType('RequestDeleteSpace', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDELETESPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeleteSpace)
  })
_sym_db.RegisterMessage(RequestDeleteSpace)

RequestLoadSpaces = _reflection.GeneratedProtocolMessageType('RequestLoadSpaces', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADSPACES,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadSpaces)
  })
_sym_db.RegisterMessage(RequestLoadSpaces)

ResponseLoadSpaces = _reflection.GeneratedProtocolMessageType('ResponseLoadSpaces', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADSPACES,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadSpaces)
  })
_sym_db.RegisterMessage(ResponseLoadSpaces)

RequestStreamSpaceMembers = _reflection.GeneratedProtocolMessageType('RequestStreamSpaceMembers', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSTREAMSPACEMEMBERS,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStreamSpaceMembers)
  })
_sym_db.RegisterMessage(RequestStreamSpaceMembers)

SpaceMemberWithPeer = _reflection.GeneratedProtocolMessageType('SpaceMemberWithPeer', (_message.Message,), {
  'DESCRIPTOR' : _SPACEMEMBERWITHPEER,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SpaceMemberWithPeer)
  })
_sym_db.RegisterMessage(SpaceMemberWithPeer)

RequestSetTitle = _reflection.GeneratedProtocolMessageType('RequestSetTitle', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETTITLE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetTitle)
  })
_sym_db.RegisterMessage(RequestSetTitle)

RequestSetShortname = _reflection.GeneratedProtocolMessageType('RequestSetShortname', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETSHORTNAME,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetShortname)
  })
_sym_db.RegisterMessage(RequestSetShortname)

RequestSetAbout = _reflection.GeneratedProtocolMessageType('RequestSetAbout', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETABOUT,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetAbout)
  })
_sym_db.RegisterMessage(RequestSetAbout)

RequestSetAvatar = _reflection.GeneratedProtocolMessageType('RequestSetAvatar', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETAVATAR,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetAvatar)
  })
_sym_db.RegisterMessage(RequestSetAvatar)

RequestSpaceInvite = _reflection.GeneratedProtocolMessageType('RequestSpaceInvite', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSPACEINVITE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSpaceInvite)
  })
_sym_db.RegisterMessage(RequestSpaceInvite)

RequestSpaceKick = _reflection.GeneratedProtocolMessageType('RequestSpaceKick', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSPACEKICK,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSpaceKick)
  })
_sym_db.RegisterMessage(RequestSpaceKick)

RequestSpaceLeave = _reflection.GeneratedProtocolMessageType('RequestSpaceLeave', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSPACELEAVE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSpaceLeave)
  })
_sym_db.RegisterMessage(RequestSpaceLeave)

RequestGetSpaceInviteUrl = _reflection.GeneratedProtocolMessageType('RequestGetSpaceInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETSPACEINVITEURL,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetSpaceInviteUrl)
  })
_sym_db.RegisterMessage(RequestGetSpaceInviteUrl)

ResponseSpaceInviteUrl = _reflection.GeneratedProtocolMessageType('ResponseSpaceInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESPACEINVITEURL,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSpaceInviteUrl)
  })
_sym_db.RegisterMessage(ResponseSpaceInviteUrl)

RequestRevokeSpaceInviteUrl = _reflection.GeneratedProtocolMessageType('RequestRevokeSpaceInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREVOKESPACEINVITEURL,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRevokeSpaceInviteUrl)
  })
_sym_db.RegisterMessage(RequestRevokeSpaceInviteUrl)


DESCRIPTOR._options = None
_REQUESTCREATESPACE._options = None
_RESPONSESPACE._options = None
_RESPONSESPACEMEMBER._options = None
_REQUESTDELETESPACE._options = None
_REQUESTLOADSPACES._options = None
_RESPONSELOADSPACES._options = None
_REQUESTSTREAMSPACEMEMBERS._options = None
_REQUESTSETTITLE._options = None
_REQUESTSETSHORTNAME._options = None
_REQUESTSETABOUT._options = None
_REQUESTSETAVATAR._options = None
_REQUESTSPACEINVITE._options = None
_REQUESTSPACEKICK._options = None
_REQUESTSPACELEAVE._options = None
_REQUESTGETSPACEINVITEURL._options = None
_RESPONSESPACEINVITEURL._options = None
_REQUESTREVOKESPACEINVITEURL._options = None

_SPACES = _descriptor.ServiceDescriptor(
  name='Spaces',
  full_name='dialog.Spaces',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3249,
  serialized_end=4195,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSpace',
    full_name='dialog.Spaces.CreateSpace',
    index=0,
    containing_service=None,
    input_type=_REQUESTCREATESPACE,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSpace',
    full_name='dialog.Spaces.DeleteSpace',
    index=1,
    containing_service=None,
    input_type=_REQUESTDELETESPACE,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTitle',
    full_name='dialog.Spaces.SetTitle',
    index=2,
    containing_service=None,
    input_type=_REQUESTSETTITLE,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetShortname',
    full_name='dialog.Spaces.SetShortname',
    index=3,
    containing_service=None,
    input_type=_REQUESTSETSHORTNAME,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAbout',
    full_name='dialog.Spaces.SetAbout',
    index=4,
    containing_service=None,
    input_type=_REQUESTSETABOUT,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAvatar',
    full_name='dialog.Spaces.SetAvatar',
    index=5,
    containing_service=None,
    input_type=_REQUESTSETAVATAR,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadSpaces',
    full_name='dialog.Spaces.LoadSpaces',
    index=6,
    containing_service=None,
    input_type=_REQUESTLOADSPACES,
    output_type=_RESPONSELOADSPACES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadSpaceMembers',
    full_name='dialog.Spaces.LoadSpaceMembers',
    index=7,
    containing_service=None,
    input_type=_REQUESTSTREAMSPACEMEMBERS,
    output_type=_SPACEMEMBERWITHPEER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Invite',
    full_name='dialog.Spaces.Invite',
    index=8,
    containing_service=None,
    input_type=_REQUESTSPACEINVITE,
    output_type=_RESPONSESPACEMEMBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Kick',
    full_name='dialog.Spaces.Kick',
    index=9,
    containing_service=None,
    input_type=_REQUESTSPACEKICK,
    output_type=_RESPONSESPACEMEMBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Leave',
    full_name='dialog.Spaces.Leave',
    index=10,
    containing_service=None,
    input_type=_REQUESTSPACELEAVE,
    output_type=_RESPONSESPACEMEMBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSpaceInviteUrl',
    full_name='dialog.Spaces.GetSpaceInviteUrl',
    index=11,
    containing_service=None,
    input_type=_REQUESTGETSPACEINVITEURL,
    output_type=_RESPONSESPACEINVITEURL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeSpaceInviteUrl',
    full_name='dialog.Spaces.RevokeSpaceInviteUrl',
    index=12,
    containing_service=None,
    input_type=_REQUESTREVOKESPACEINVITEURL,
    output_type=_RESPONSESPACEINVITEURL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SPACES)

DESCRIPTOR.services_by_name['Spaces'] = _SPACES

# @@protoc_insertion_point(module_scope)
