# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reactions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import peers_pb2 as peers__pb2
from . import definitions_pb2 as definitions__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='reactions.proto',
  package='dialog.reactions',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0freactions.proto\x12\x10\x64ialog.reactions\x1a\x1cgoogle/api/annotations.proto\x1a\x0bpeers.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x15scalapb/scalapb.proto\x1a\x1bgoogle/protobuf/empty.proto\"=\n\x08Reaction\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05users\x18\x02 \x03(\x05\x12\x14\n\x0cusers_amount\x18\x03 \x01(\x05\"a\n\x10MessageReactions\x12\x1e\n\x03mid\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12-\n\treactions\x18\x02 \x03(\x0b\x32\x1a.dialog.reactions.Reaction\"\x9e\x01\n\x16MessageReactionsUpdate\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12;\n\x0fmessageReaction\x18\x02 \x01(\x0b\x32\".dialog.reactions.MessageReactions\x12\x12\n\npeer_clock\x18\x03 \x01(\x03\x12\x17\n\x0fprev_peer_clock\x18\x04 \x01(\x03\"E\n\x13GetReactionsRequest\x12\x12\n\nfrom_clock\x18\x01 \x01(\x03\x12\x1a\n\x04peer\x18\x02 \x01(\x0b\x32\x0c.dialog.Peer\"\x80\x01\n\x14GetReactionsResponse\x12<\n\x10messageReactions\x18\x01 \x03(\x0b\x32\".dialog.reactions.MessageReactions\x12\x12\n\npeer_clock\x18\x02 \x01(\x03\x12\x16\n\x0enext_available\x18\x03 \x01(\x08\"e\n\x19RequestSetMessageReaction\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12\x1e\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\"h\n\x1cRequestRemoveMessageReaction\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12\x1e\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t2\xbc\x03\n\tReactions\x12\x89\x01\n\x0cGetReactions\x12%.dialog.reactions.GetReactionsRequest\x1a&.dialog.reactions.GetReactionsResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Reactions/GetReactions:\x01*\x12\x8b\x01\n\x12MessageSetReaction\x12+.dialog.reactions.RequestSetMessageReaction\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Reactions/MessageSetReaction:\x01*\x12\x94\x01\n\x15MessageRemoveReaction\x12..dialog.reactions.RequestRemoveMessageReaction\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Reactions/MessageRemoveReaction:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_REACTION = _descriptor.Descriptor(
  name='Reaction',
  full_name='dialog.reactions.Reaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.reactions.Reaction.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.reactions.Reaction.users', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users_amount', full_name='dialog.reactions.Reaction.users_amount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=212,
)


_MESSAGEREACTIONS = _descriptor.Descriptor(
  name='MessageReactions',
  full_name='dialog.reactions.MessageReactions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.reactions.MessageReactions.mid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='dialog.reactions.MessageReactions.reactions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=311,
)


_MESSAGEREACTIONSUPDATE = _descriptor.Descriptor(
  name='MessageReactionsUpdate',
  full_name='dialog.reactions.MessageReactionsUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.MessageReactionsUpdate.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageReaction', full_name='dialog.reactions.MessageReactionsUpdate.messageReaction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_clock', full_name='dialog.reactions.MessageReactionsUpdate.peer_clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_peer_clock', full_name='dialog.reactions.MessageReactionsUpdate.prev_peer_clock', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=472,
)


_GETREACTIONSREQUEST = _descriptor.Descriptor(
  name='GetReactionsRequest',
  full_name='dialog.reactions.GetReactionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_clock', full_name='dialog.reactions.GetReactionsRequest.from_clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.GetReactionsRequest.peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=543,
)


_GETREACTIONSRESPONSE = _descriptor.Descriptor(
  name='GetReactionsResponse',
  full_name='dialog.reactions.GetReactionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageReactions', full_name='dialog.reactions.GetReactionsResponse.messageReactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_clock', full_name='dialog.reactions.GetReactionsResponse.peer_clock', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_available', full_name='dialog.reactions.GetReactionsResponse.next_available', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=674,
)


_REQUESTSETMESSAGEREACTION = _descriptor.Descriptor(
  name='RequestSetMessageReaction',
  full_name='dialog.reactions.RequestSetMessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.RequestSetMessageReaction.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.reactions.RequestSetMessageReaction.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.reactions.RequestSetMessageReaction.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=777,
)


_REQUESTREMOVEMESSAGEREACTION = _descriptor.Descriptor(
  name='RequestRemoveMessageReaction',
  full_name='dialog.reactions.RequestRemoveMessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.RequestRemoveMessageReaction.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.reactions.RequestRemoveMessageReaction.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.reactions.RequestRemoveMessageReaction.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=883,
)

_MESSAGEREACTIONS.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_MESSAGEREACTIONS.fields_by_name['reactions'].message_type = _REACTION
_MESSAGEREACTIONSUPDATE.fields_by_name['peer'].message_type = peers__pb2._PEER
_MESSAGEREACTIONSUPDATE.fields_by_name['messageReaction'].message_type = _MESSAGEREACTIONS
_GETREACTIONSREQUEST.fields_by_name['peer'].message_type = peers__pb2._PEER
_GETREACTIONSRESPONSE.fields_by_name['messageReactions'].message_type = _MESSAGEREACTIONS
_REQUESTSETMESSAGEREACTION.fields_by_name['peer'].message_type = peers__pb2._PEER
_REQUESTSETMESSAGEREACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTREMOVEMESSAGEREACTION.fields_by_name['peer'].message_type = peers__pb2._PEER
_REQUESTREMOVEMESSAGEREACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
DESCRIPTOR.message_types_by_name['Reaction'] = _REACTION
DESCRIPTOR.message_types_by_name['MessageReactions'] = _MESSAGEREACTIONS
DESCRIPTOR.message_types_by_name['MessageReactionsUpdate'] = _MESSAGEREACTIONSUPDATE
DESCRIPTOR.message_types_by_name['GetReactionsRequest'] = _GETREACTIONSREQUEST
DESCRIPTOR.message_types_by_name['GetReactionsResponse'] = _GETREACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['RequestSetMessageReaction'] = _REQUESTSETMESSAGEREACTION
DESCRIPTOR.message_types_by_name['RequestRemoveMessageReaction'] = _REQUESTREMOVEMESSAGEREACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reaction = _reflection.GeneratedProtocolMessageType('Reaction', (_message.Message,), {
  'DESCRIPTOR' : _REACTION,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.Reaction)
  })
_sym_db.RegisterMessage(Reaction)

MessageReactions = _reflection.GeneratedProtocolMessageType('MessageReactions', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREACTIONS,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.MessageReactions)
  })
_sym_db.RegisterMessage(MessageReactions)

MessageReactionsUpdate = _reflection.GeneratedProtocolMessageType('MessageReactionsUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREACTIONSUPDATE,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.MessageReactionsUpdate)
  })
_sym_db.RegisterMessage(MessageReactionsUpdate)

GetReactionsRequest = _reflection.GeneratedProtocolMessageType('GetReactionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREACTIONSREQUEST,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.GetReactionsRequest)
  })
_sym_db.RegisterMessage(GetReactionsRequest)

GetReactionsResponse = _reflection.GeneratedProtocolMessageType('GetReactionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREACTIONSRESPONSE,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.GetReactionsResponse)
  })
_sym_db.RegisterMessage(GetReactionsResponse)

RequestSetMessageReaction = _reflection.GeneratedProtocolMessageType('RequestSetMessageReaction', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETMESSAGEREACTION,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.RequestSetMessageReaction)
  })
_sym_db.RegisterMessage(RequestSetMessageReaction)

RequestRemoveMessageReaction = _reflection.GeneratedProtocolMessageType('RequestRemoveMessageReaction', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREMOVEMESSAGEREACTION,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.RequestRemoveMessageReaction)
  })
_sym_db.RegisterMessage(RequestRemoveMessageReaction)


DESCRIPTOR._options = None

_REACTIONS = _descriptor.ServiceDescriptor(
  name='Reactions',
  full_name='dialog.reactions.Reactions',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=886,
  serialized_end=1330,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetReactions',
    full_name='dialog.reactions.Reactions.GetReactions',
    index=0,
    containing_service=None,
    input_type=_GETREACTIONSREQUEST,
    output_type=_GETREACTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Reactions/GetReactions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MessageSetReaction',
    full_name='dialog.reactions.Reactions.MessageSetReaction',
    index=1,
    containing_service=None,
    input_type=_REQUESTSETMESSAGEREACTION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002*\"%/v1/grpc/Reactions/MessageSetReaction:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MessageRemoveReaction',
    full_name='dialog.reactions.Reactions.MessageRemoveReaction',
    index=2,
    containing_service=None,
    input_type=_REQUESTREMOVEMESSAGEREACTION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002-\"(/v1/grpc/Reactions/MessageRemoveReaction:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REACTIONS)

DESCRIPTOR.services_by_name['Reactions'] = _REACTIONS

# @@protoc_insertion_point(module_scope)
