# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: privacy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='privacy.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rprivacy.proto\x12\x06\x64ialog\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x15scalapb/scalapb.proto\"b\n\x10RequestBlockUser\x12\x30\n\x04peer\x18\x01 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"d\n\x12RequestUnblockUser\x12\x30\n\x04peer\x18\x01 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"T\n\x17RequestLoadBlockedUsers:9\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"b\n\x18ResponseLoadBlockedUsers\x12\'\n\nuser_peers\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"/\n\x11UpdateUserBlocked\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"1\n\x13UpdateUserUnblocked\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible2\xdb\x02\n\x07Privacy\x12\x61\n\tBlockUser\x12\x18.dialog.RequestBlockUser\x1a\x13.dialog.ResponseSeq\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Privacy/BlockUser:\x01*\x12g\n\x0bUnblockUser\x12\x1a.dialog.RequestUnblockUser\x1a\x13.dialog.ResponseSeq\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Privacy/UnblockUser:\x01*\x12\x83\x01\n\x10LoadBlockedUsers\x12\x1f.dialog.RequestLoadBlockedUsers\x1a .dialog.ResponseLoadBlockedUsers\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Privacy/LoadBlockedUsers:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTBLOCKUSER = _descriptor.Descriptor(
  name='RequestBlockUser',
  full_name='dialog.RequestBlockUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestBlockUser.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=229,
)


_REQUESTUNBLOCKUSER = _descriptor.Descriptor(
  name='RequestUnblockUser',
  full_name='dialog.RequestUnblockUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestUnblockUser.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=331,
)


_REQUESTLOADBLOCKEDUSERS = _descriptor.Descriptor(
  name='RequestLoadBlockedUsers',
  full_name='dialog.RequestLoadBlockedUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=417,
)


_RESPONSELOADBLOCKEDUSERS = _descriptor.Descriptor(
  name='ResponseLoadBlockedUsers',
  full_name='dialog.ResponseLoadBlockedUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseLoadBlockedUsers.user_peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=517,
)


_UPDATEUSERBLOCKED = _descriptor.Descriptor(
  name='UpdateUserBlocked',
  full_name='dialog.UpdateUserBlocked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserBlocked.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=566,
)


_UPDATEUSERUNBLOCKED = _descriptor.Descriptor(
  name='UpdateUserUnblocked',
  full_name='dialog.UpdateUserUnblocked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserUnblocked.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=617,
)

_REQUESTBLOCKUSER.fields_by_name['peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTUNBLOCKUSER.fields_by_name['peer'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADBLOCKEDUSERS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
DESCRIPTOR.message_types_by_name['RequestBlockUser'] = _REQUESTBLOCKUSER
DESCRIPTOR.message_types_by_name['RequestUnblockUser'] = _REQUESTUNBLOCKUSER
DESCRIPTOR.message_types_by_name['RequestLoadBlockedUsers'] = _REQUESTLOADBLOCKEDUSERS
DESCRIPTOR.message_types_by_name['ResponseLoadBlockedUsers'] = _RESPONSELOADBLOCKEDUSERS
DESCRIPTOR.message_types_by_name['UpdateUserBlocked'] = _UPDATEUSERBLOCKED
DESCRIPTOR.message_types_by_name['UpdateUserUnblocked'] = _UPDATEUSERUNBLOCKED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestBlockUser = _reflection.GeneratedProtocolMessageType('RequestBlockUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBLOCKUSER,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestBlockUser)
  })
_sym_db.RegisterMessage(RequestBlockUser)

RequestUnblockUser = _reflection.GeneratedProtocolMessageType('RequestUnblockUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNBLOCKUSER,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnblockUser)
  })
_sym_db.RegisterMessage(RequestUnblockUser)

RequestLoadBlockedUsers = _reflection.GeneratedProtocolMessageType('RequestLoadBlockedUsers', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADBLOCKEDUSERS,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadBlockedUsers)
  })
_sym_db.RegisterMessage(RequestLoadBlockedUsers)

ResponseLoadBlockedUsers = _reflection.GeneratedProtocolMessageType('ResponseLoadBlockedUsers', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADBLOCKEDUSERS,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadBlockedUsers)
  })
_sym_db.RegisterMessage(ResponseLoadBlockedUsers)

UpdateUserBlocked = _reflection.GeneratedProtocolMessageType('UpdateUserBlocked', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERBLOCKED,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserBlocked)
  })
_sym_db.RegisterMessage(UpdateUserBlocked)

UpdateUserUnblocked = _reflection.GeneratedProtocolMessageType('UpdateUserUnblocked', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERUNBLOCKED,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserUnblocked)
  })
_sym_db.RegisterMessage(UpdateUserUnblocked)


DESCRIPTOR._options = None
_REQUESTBLOCKUSER.fields_by_name['peer']._options = None
_REQUESTBLOCKUSER._options = None
_REQUESTUNBLOCKUSER.fields_by_name['peer']._options = None
_REQUESTUNBLOCKUSER._options = None
_REQUESTLOADBLOCKEDUSERS._options = None
_RESPONSELOADBLOCKEDUSERS._options = None
_UPDATEUSERBLOCKED.fields_by_name['uid']._options = None
_UPDATEUSERUNBLOCKED.fields_by_name['uid']._options = None

_PRIVACY = _descriptor.ServiceDescriptor(
  name='Privacy',
  full_name='dialog.Privacy',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=620,
  serialized_end=967,
  methods=[
  _descriptor.MethodDescriptor(
    name='BlockUser',
    full_name='dialog.Privacy.BlockUser',
    index=0,
    containing_service=None,
    input_type=_REQUESTBLOCKUSER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/grpc/Privacy/BlockUser:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnblockUser',
    full_name='dialog.Privacy.UnblockUser',
    index=1,
    containing_service=None,
    input_type=_REQUESTUNBLOCKUSER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/grpc/Privacy/UnblockUser:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadBlockedUsers',
    full_name='dialog.Privacy.LoadBlockedUsers',
    index=2,
    containing_service=None,
    input_type=_REQUESTLOADBLOCKEDUSERS,
    output_type=_RESPONSELOADBLOCKEDUSERS,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Privacy/LoadBlockedUsers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PRIVACY)

DESCRIPTOR.services_by_name['Privacy'] = _PRIVACY

# @@protoc_insertion_point(module_scope)
