# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import config_sync_pb2 as config__sync__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class ConfigSyncStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetParameters = channel.unary_unary(
                '/dialog.ConfigSync/GetParameters',
                request_serializer=config__sync__pb2.RequestGetParameters.SerializeToString,
                response_deserializer=config__sync__pb2.ResponseGetParameters.FromString,
                )
        self.EditParameter = channel.unary_unary(
                '/dialog.ConfigSync/EditParameter',
                request_serializer=config__sync__pb2.RequestEditParameter.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.FeatureFlags = channel.unary_unary(
                '/dialog.ConfigSync/FeatureFlags',
                request_serializer=config__sync__pb2.RequestFeatureFlags.SerializeToString,
                response_deserializer=config__sync__pb2.ResponseFeatureFlags.FromString,
                )


class ConfigSyncServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditParameter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureFlags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigSyncServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParameters,
                    request_deserializer=config__sync__pb2.RequestGetParameters.FromString,
                    response_serializer=config__sync__pb2.ResponseGetParameters.SerializeToString,
            ),
            'EditParameter': grpc.unary_unary_rpc_method_handler(
                    servicer.EditParameter,
                    request_deserializer=config__sync__pb2.RequestEditParameter.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'FeatureFlags': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureFlags,
                    request_deserializer=config__sync__pb2.RequestFeatureFlags.FromString,
                    response_serializer=config__sync__pb2.ResponseFeatureFlags.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.ConfigSync', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConfigSync(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ConfigSync/GetParameters',
            config__sync__pb2.RequestGetParameters.SerializeToString,
            config__sync__pb2.ResponseGetParameters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditParameter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ConfigSync/EditParameter',
            config__sync__pb2.RequestEditParameter.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureFlags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ConfigSync/FeatureFlags',
            config__sync__pb2.RequestFeatureFlags.SerializeToString,
            config__sync__pb2.ResponseFeatureFlags.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
