# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: miniappsregistry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import definitions_pb2 as definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='miniappsregistry.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16miniappsregistry.proto\x12\x06\x64ialog\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x64\x65\x66initions.proto\"\xc7\x02\n\x07MiniApp\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12!\n\x08\x61pp_type\x18\x02 \x01(\x0e\x32\x0f.dialog.AppType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x0c\n\x04icon\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\x16\n\x0emodified_at_ts\x18\n \x01(\x03\x12\x12\n\nis_enabled\x18\x0b \x01(\x08\x12-\n\x07locales\x18\x0c \x03(\x0b\x32\x1c.dialog.MiniApp.LocalesEntry\x12\x13\n\x0bpermissions\x18\r \x03(\t\x1a.\n\x0cLocalesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\x95\x02\n\rUpdateMiniApp\x12\x39\n\rapp_lifecycle\x18\x01 \x01(\x0e\x32\".dialog.UpdateMiniApp.AppLifecycle\x12!\n\x08\x61pp_data\x18\x02 \x01(\x0b\x32\x0f.dialog.MiniApp\x12\x12\n\nprev_clock\x18\x03 \x01(\x03\"\x91\x01\n\x0c\x41ppLifecycle\x12\x18\n\x14\x41PPLIFECYCLE_CREATED\x10\x00\x12\x18\n\x14\x41PPLIFECYCLE_UPDATED\x10\x01\x12\x18\n\x14\x41PPLIFECYCLE_ENABLED\x10\x02\x12\x19\n\x15\x41PPLIFECYCLE_DISABLED\x10\x03\x12\x18\n\x14\x41PPLIFECYCLE_DELETED\x10\x04\"$\n\x0eGetAppsRequest\x12\x12\n\nfrom_clock\x18\x01 \x01(\x03\"?\n\x0fGetAppsResponse\x12\x1d\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x0f.dialog.MiniApp\x12\r\n\x05\x63lock\x18\x02 \x01(\x03\" \n\x0e\x46indAppRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\"/\n\x0f\x46indAppResponse\x12\x1c\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x0f.dialog.MiniApp\"<\n\x17IssueAccessTokenRequest\x12!\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\"+\n\x13\x41\x63\x63\x65ssTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"|\n\x15GetExtensionsResponse\x12\x32\n\x12message_extensions\x18\x01 \x03(\x0b\x32\x16.dialog.ExtensionPoint\x12/\n\x0f\x63hat_extensions\x18\x02 \x03(\x0b\x32\x16.dialog.ExtensionPoint\"\xce\x01\n\x0e\x45xtensionPoint\x12!\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x37\n\x12message_conditions\x18\x04 \x01(\x0b\x32\x19.dialog.MessageConditionsH\x00\x12\x33\n\x10group_conditions\x18\x05 \x01(\x0b\x32\x17.dialog.GroupConditionsH\x00\x42\x0c\n\nconditions\"\xbb\x02\n\x11MessageConditions\x12\x45\n\x11message_condition\x18\x01 \x03(\x0b\x32*.dialog.MessageConditions.MessageCondition\x1a\xde\x01\n\x10MessageCondition\x12\x14\n\x0ctext_message\x18\x01 \x01(\t\x12V\n\x10\x64ocument_message\x18\x02 \x01(\x0b\x32<.dialog.MessageConditions.MessageCondition.DocumentCondition\x1a\\\n\x11\x44ocumentCondition\x12\x10\n\x08is_image\x18\x01 \x01(\x08\x12\x10\n\x08is_video\x18\x02 \x01(\x08\x12\x10\n\x08is_audio\x18\x03 \x01(\x08\x12\x11\n\tmime_type\x18\x04 \x03(\t\"\xa0\x01\n\x0fGroupConditions\x12?\n\x0fgroup_condition\x18\x01 \x03(\x0b\x32&.dialog.GroupConditions.GroupCondition\x1aL\n\x0eGroupCondition\x12\x12\n\ngroup_type\x18\x01 \x01(\t\x12\x12\n\nvisibility\x18\x02 \x01(\t\x12\x12\n\npermission\x18\x03 \x03(\t*$\n\x07\x41ppType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08WEB_VIEW\x10\x01\x32\xab\x02\n\x17\x43lientsMiniAppsRegistry\x12:\n\x07\x46indApp\x12\x16.dialog.FindAppRequest\x1a\x17.dialog.FindAppResponse\x12:\n\x07GetApps\x12\x16.dialog.GetAppsRequest\x1a\x17.dialog.GetAppsResponse\x12\x46\n\rGetExtensions\x12\x16.google.protobuf.Empty\x1a\x1d.dialog.GetExtensionsResponse\x12P\n\x10IssueAccessToken\x12\x1f.dialog.IssueAccessTokenRequest\x1a\x1b.dialog.AccessTokenResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,])

_APPTYPE = _descriptor.EnumDescriptor(
  name='AppType',
  full_name='dialog.AppType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEB_VIEW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1833,
  serialized_end=1869,
)
_sym_db.RegisterEnumDescriptor(_APPTYPE)

AppType = enum_type_wrapper.EnumTypeWrapper(_APPTYPE)
UNKNOWN = 0
WEB_VIEW = 1


_UPDATEMINIAPP_APPLIFECYCLE = _descriptor.EnumDescriptor(
  name='AppLifecycle',
  full_name='dialog.UpdateMiniApp.AppLifecycle',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_CREATED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_UPDATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_ENABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_DISABLED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=577,
  serialized_end=722,
)
_sym_db.RegisterEnumDescriptor(_UPDATEMINIAPP_APPLIFECYCLE)


_MINIAPP_LOCALESENTRY = _descriptor.Descriptor(
  name='LocalesEntry',
  full_name='dialog.MiniApp.LocalesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.MiniApp.LocalesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.MiniApp.LocalesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=430,
)

_MINIAPP = _descriptor.Descriptor(
  name='MiniApp',
  full_name='dialog.MiniApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.MiniApp.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_type', full_name='dialog.MiniApp.app_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.MiniApp.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='dialog.MiniApp.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='dialog.MiniApp.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='dialog.MiniApp.icon', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='dialog.MiniApp.link', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_at_ts', full_name='dialog.MiniApp.modified_at_ts', index=7,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='dialog.MiniApp.is_enabled', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locales', full_name='dialog.MiniApp.locales', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.MiniApp.permissions', index=10,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MINIAPP_LOCALESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=442,
)


_UPDATEMINIAPP = _descriptor.Descriptor(
  name='UpdateMiniApp',
  full_name='dialog.UpdateMiniApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_lifecycle', full_name='dialog.UpdateMiniApp.app_lifecycle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_data', full_name='dialog.UpdateMiniApp.app_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_clock', full_name='dialog.UpdateMiniApp.prev_clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEMINIAPP_APPLIFECYCLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=722,
)


_GETAPPSREQUEST = _descriptor.Descriptor(
  name='GetAppsRequest',
  full_name='dialog.GetAppsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_clock', full_name='dialog.GetAppsRequest.from_clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=760,
)


_GETAPPSRESPONSE = _descriptor.Descriptor(
  name='GetAppsResponse',
  full_name='dialog.GetAppsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='dialog.GetAppsResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.GetAppsResponse.clock', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=825,
)


_FINDAPPREQUEST = _descriptor.Descriptor(
  name='FindAppRequest',
  full_name='dialog.FindAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.FindAppRequest.app_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=859,
)


_FINDAPPRESPONSE = _descriptor.Descriptor(
  name='FindAppResponse',
  full_name='dialog.FindAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app', full_name='dialog.FindAppResponse.app', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=908,
)


_ISSUEACCESSTOKENREQUEST = _descriptor.Descriptor(
  name='IssueAccessTokenRequest',
  full_name='dialog.IssueAccessTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.IssueAccessTokenRequest.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=970,
)


_ACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='AccessTokenResponse',
  full_name='dialog.AccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='dialog.AccessTokenResponse.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1015,
)


_GETEXTENSIONSRESPONSE = _descriptor.Descriptor(
  name='GetExtensionsResponse',
  full_name='dialog.GetExtensionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_extensions', full_name='dialog.GetExtensionsResponse.message_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_extensions', full_name='dialog.GetExtensionsResponse.chat_extensions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1141,
)


_EXTENSIONPOINT = _descriptor.Descriptor(
  name='ExtensionPoint',
  full_name='dialog.ExtensionPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.ExtensionPoint.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='dialog.ExtensionPoint.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='dialog.ExtensionPoint.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_conditions', full_name='dialog.ExtensionPoint.message_conditions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_conditions', full_name='dialog.ExtensionPoint.group_conditions', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='conditions', full_name='dialog.ExtensionPoint.conditions',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1144,
  serialized_end=1350,
)


_MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION = _descriptor.Descriptor(
  name='DocumentCondition',
  full_name='dialog.MessageConditions.MessageCondition.DocumentCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_image', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.is_image', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_video', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.is_video', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_audio', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.is_audio', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.mime_type', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1576,
  serialized_end=1668,
)

_MESSAGECONDITIONS_MESSAGECONDITION = _descriptor.Descriptor(
  name='MessageCondition',
  full_name='dialog.MessageConditions.MessageCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_message', full_name='dialog.MessageConditions.MessageCondition.text_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document_message', full_name='dialog.MessageConditions.MessageCondition.document_message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1668,
)

_MESSAGECONDITIONS = _descriptor.Descriptor(
  name='MessageConditions',
  full_name='dialog.MessageConditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_condition', full_name='dialog.MessageConditions.message_condition', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGECONDITIONS_MESSAGECONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1668,
)


_GROUPCONDITIONS_GROUPCONDITION = _descriptor.Descriptor(
  name='GroupCondition',
  full_name='dialog.GroupConditions.GroupCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.GroupConditions.GroupCondition.group_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='dialog.GroupConditions.GroupCondition.visibility', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='dialog.GroupConditions.GroupCondition.permission', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1831,
)

_GROUPCONDITIONS = _descriptor.Descriptor(
  name='GroupConditions',
  full_name='dialog.GroupConditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_condition', full_name='dialog.GroupConditions.group_condition', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GROUPCONDITIONS_GROUPCONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1831,
)

_MINIAPP_LOCALESENTRY.containing_type = _MINIAPP
_MINIAPP.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_MINIAPP.fields_by_name['app_type'].enum_type = _APPTYPE
_MINIAPP.fields_by_name['locales'].message_type = _MINIAPP_LOCALESENTRY
_UPDATEMINIAPP.fields_by_name['app_lifecycle'].enum_type = _UPDATEMINIAPP_APPLIFECYCLE
_UPDATEMINIAPP.fields_by_name['app_data'].message_type = _MINIAPP
_UPDATEMINIAPP_APPLIFECYCLE.containing_type = _UPDATEMINIAPP
_GETAPPSRESPONSE.fields_by_name['apps'].message_type = _MINIAPP
_FINDAPPRESPONSE.fields_by_name['app'].message_type = _MINIAPP
_ISSUEACCESSTOKENREQUEST.fields_by_name['app_id'].message_type = definitions__pb2._UUIDVALUE
_GETEXTENSIONSRESPONSE.fields_by_name['message_extensions'].message_type = _EXTENSIONPOINT
_GETEXTENSIONSRESPONSE.fields_by_name['chat_extensions'].message_type = _EXTENSIONPOINT
_EXTENSIONPOINT.fields_by_name['app_id'].message_type = definitions__pb2._UUIDVALUE
_EXTENSIONPOINT.fields_by_name['message_conditions'].message_type = _MESSAGECONDITIONS
_EXTENSIONPOINT.fields_by_name['group_conditions'].message_type = _GROUPCONDITIONS
_EXTENSIONPOINT.oneofs_by_name['conditions'].fields.append(
  _EXTENSIONPOINT.fields_by_name['message_conditions'])
_EXTENSIONPOINT.fields_by_name['message_conditions'].containing_oneof = _EXTENSIONPOINT.oneofs_by_name['conditions']
_EXTENSIONPOINT.oneofs_by_name['conditions'].fields.append(
  _EXTENSIONPOINT.fields_by_name['group_conditions'])
_EXTENSIONPOINT.fields_by_name['group_conditions'].containing_oneof = _EXTENSIONPOINT.oneofs_by_name['conditions']
_MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION.containing_type = _MESSAGECONDITIONS_MESSAGECONDITION
_MESSAGECONDITIONS_MESSAGECONDITION.fields_by_name['document_message'].message_type = _MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION
_MESSAGECONDITIONS_MESSAGECONDITION.containing_type = _MESSAGECONDITIONS
_MESSAGECONDITIONS.fields_by_name['message_condition'].message_type = _MESSAGECONDITIONS_MESSAGECONDITION
_GROUPCONDITIONS_GROUPCONDITION.containing_type = _GROUPCONDITIONS
_GROUPCONDITIONS.fields_by_name['group_condition'].message_type = _GROUPCONDITIONS_GROUPCONDITION
DESCRIPTOR.message_types_by_name['MiniApp'] = _MINIAPP
DESCRIPTOR.message_types_by_name['UpdateMiniApp'] = _UPDATEMINIAPP
DESCRIPTOR.message_types_by_name['GetAppsRequest'] = _GETAPPSREQUEST
DESCRIPTOR.message_types_by_name['GetAppsResponse'] = _GETAPPSRESPONSE
DESCRIPTOR.message_types_by_name['FindAppRequest'] = _FINDAPPREQUEST
DESCRIPTOR.message_types_by_name['FindAppResponse'] = _FINDAPPRESPONSE
DESCRIPTOR.message_types_by_name['IssueAccessTokenRequest'] = _ISSUEACCESSTOKENREQUEST
DESCRIPTOR.message_types_by_name['AccessTokenResponse'] = _ACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['GetExtensionsResponse'] = _GETEXTENSIONSRESPONSE
DESCRIPTOR.message_types_by_name['ExtensionPoint'] = _EXTENSIONPOINT
DESCRIPTOR.message_types_by_name['MessageConditions'] = _MESSAGECONDITIONS
DESCRIPTOR.message_types_by_name['GroupConditions'] = _GROUPCONDITIONS
DESCRIPTOR.enum_types_by_name['AppType'] = _APPTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MiniApp = _reflection.GeneratedProtocolMessageType('MiniApp', (_message.Message,), {

  'LocalesEntry' : _reflection.GeneratedProtocolMessageType('LocalesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MINIAPP_LOCALESENTRY,
    '__module__' : 'miniappsregistry_pb2'
    # @@protoc_insertion_point(class_scope:dialog.MiniApp.LocalesEntry)
    })
  ,
  'DESCRIPTOR' : _MINIAPP,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MiniApp)
  })
_sym_db.RegisterMessage(MiniApp)
_sym_db.RegisterMessage(MiniApp.LocalesEntry)

UpdateMiniApp = _reflection.GeneratedProtocolMessageType('UpdateMiniApp', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMINIAPP,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMiniApp)
  })
_sym_db.RegisterMessage(UpdateMiniApp)

GetAppsRequest = _reflection.GeneratedProtocolMessageType('GetAppsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPSREQUEST,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetAppsRequest)
  })
_sym_db.RegisterMessage(GetAppsRequest)

GetAppsResponse = _reflection.GeneratedProtocolMessageType('GetAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPSRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetAppsResponse)
  })
_sym_db.RegisterMessage(GetAppsResponse)

FindAppRequest = _reflection.GeneratedProtocolMessageType('FindAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDAPPREQUEST,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FindAppRequest)
  })
_sym_db.RegisterMessage(FindAppRequest)

FindAppResponse = _reflection.GeneratedProtocolMessageType('FindAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDAPPRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FindAppResponse)
  })
_sym_db.RegisterMessage(FindAppResponse)

IssueAccessTokenRequest = _reflection.GeneratedProtocolMessageType('IssueAccessTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISSUEACCESSTOKENREQUEST,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.IssueAccessTokenRequest)
  })
_sym_db.RegisterMessage(IssueAccessTokenRequest)

AccessTokenResponse = _reflection.GeneratedProtocolMessageType('AccessTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSTOKENRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AccessTokenResponse)
  })
_sym_db.RegisterMessage(AccessTokenResponse)

GetExtensionsResponse = _reflection.GeneratedProtocolMessageType('GetExtensionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTENSIONSRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetExtensionsResponse)
  })
_sym_db.RegisterMessage(GetExtensionsResponse)

ExtensionPoint = _reflection.GeneratedProtocolMessageType('ExtensionPoint', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONPOINT,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ExtensionPoint)
  })
_sym_db.RegisterMessage(ExtensionPoint)

MessageConditions = _reflection.GeneratedProtocolMessageType('MessageConditions', (_message.Message,), {

  'MessageCondition' : _reflection.GeneratedProtocolMessageType('MessageCondition', (_message.Message,), {

    'DocumentCondition' : _reflection.GeneratedProtocolMessageType('DocumentCondition', (_message.Message,), {
      'DESCRIPTOR' : _MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION,
      '__module__' : 'miniappsregistry_pb2'
      # @@protoc_insertion_point(class_scope:dialog.MessageConditions.MessageCondition.DocumentCondition)
      })
    ,
    'DESCRIPTOR' : _MESSAGECONDITIONS_MESSAGECONDITION,
    '__module__' : 'miniappsregistry_pb2'
    # @@protoc_insertion_point(class_scope:dialog.MessageConditions.MessageCondition)
    })
  ,
  'DESCRIPTOR' : _MESSAGECONDITIONS,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageConditions)
  })
_sym_db.RegisterMessage(MessageConditions)
_sym_db.RegisterMessage(MessageConditions.MessageCondition)
_sym_db.RegisterMessage(MessageConditions.MessageCondition.DocumentCondition)

GroupConditions = _reflection.GeneratedProtocolMessageType('GroupConditions', (_message.Message,), {

  'GroupCondition' : _reflection.GeneratedProtocolMessageType('GroupCondition', (_message.Message,), {
    'DESCRIPTOR' : _GROUPCONDITIONS_GROUPCONDITION,
    '__module__' : 'miniappsregistry_pb2'
    # @@protoc_insertion_point(class_scope:dialog.GroupConditions.GroupCondition)
    })
  ,
  'DESCRIPTOR' : _GROUPCONDITIONS,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupConditions)
  })
_sym_db.RegisterMessage(GroupConditions)
_sym_db.RegisterMessage(GroupConditions.GroupCondition)


_MINIAPP_LOCALESENTRY._options = None

_CLIENTSMINIAPPSREGISTRY = _descriptor.ServiceDescriptor(
  name='ClientsMiniAppsRegistry',
  full_name='dialog.ClientsMiniAppsRegistry',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1872,
  serialized_end=2171,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindApp',
    full_name='dialog.ClientsMiniAppsRegistry.FindApp',
    index=0,
    containing_service=None,
    input_type=_FINDAPPREQUEST,
    output_type=_FINDAPPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetApps',
    full_name='dialog.ClientsMiniAppsRegistry.GetApps',
    index=1,
    containing_service=None,
    input_type=_GETAPPSREQUEST,
    output_type=_GETAPPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtensions',
    full_name='dialog.ClientsMiniAppsRegistry.GetExtensions',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETEXTENSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IssueAccessToken',
    full_name='dialog.ClientsMiniAppsRegistry.IssueAccessToken',
    index=3,
    containing_service=None,
    input_type=_ISSUEACCESSTOKENREQUEST,
    output_type=_ACCESSTOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLIENTSMINIAPPSREGISTRY)

DESCRIPTOR.services_by_name['ClientsMiniAppsRegistry'] = _CLIENTSMINIAPPSREGISTRY

# @@protoc_insertion_point(module_scope)
