# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: event_bus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import peers_pb2 as peers__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='event_bus.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x65vent_bus.proto\x12\x06\x64ialog\x1a\x1cgoogle/api/annotations.proto\x1a\x0bpeers.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"n\n\x13RequestJoinEventBus\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07timeout\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"H\n\x14ResponseJoinEventBus\x12\x11\n\tdevice_id\x18\x01 \x01(\x03:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"s\n\x18RequestKeepAliveEventBus\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07timeout\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x94\x01\n\x15RequestPostToEventBus\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65stinations\x18\x02 \x03(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x07message\x18\x03 \x01(\x0c\x42\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa7\x01\n\x1dUpdateEventBusDeviceConnected\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tdevice_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12)\n\x04peer\x18\x04 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\"\xaa\x01\n UpdateEventBusDeviceDisconnected\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07user_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tdevice_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12)\n\x04peer\x18\x04 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\"\x9c\x01\n\x15UpdateEventBusMessage\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tsender_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10sender_device_id\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x07message\x18\x04 \x01(\x0c\x42\x0c\x8a\xea\x30\x08\n\x06hidden\"3\n\x16UpdateEventBusDisposed\x12\x19\n\x02id\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible2\xf1\x02\n\x08\x45ventBus\x12t\n\x0cJoinEventBus\x12\x1b.dialog.RequestJoinEventBus\x1a\x1c.dialog.ResponseJoinEventBus\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/EventBus/JoinEventBus:\x01*\x12{\n\x11KeepAliveEventBus\x12 .dialog.RequestKeepAliveEventBus\x1a\x14.dialog.ResponseVoid\".\x82\xd3\xe4\x93\x02(\"#/v1/grpc/EventBus/KeepAliveEventBus:\x01*\x12r\n\x0ePostToEventBus\x12\x1d.dialog.RequestPostToEventBus\x1a\x14.dialog.ResponseVoid\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/EventBus/PostToEventBus:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTJOINEVENTBUS = _descriptor.Descriptor(
  name='RequestJoinEventBus',
  full_name='dialog.RequestJoinEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestJoinEventBus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestJoinEventBus.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=243,
)


_RESPONSEJOINEVENTBUS = _descriptor.Descriptor(
  name='ResponseJoinEventBus',
  full_name='dialog.ResponseJoinEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.ResponseJoinEventBus.device_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=317,
)


_REQUESTKEEPALIVEEVENTBUS = _descriptor.Descriptor(
  name='RequestKeepAliveEventBus',
  full_name='dialog.RequestKeepAliveEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestKeepAliveEventBus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestKeepAliveEventBus.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=434,
)


_REQUESTPOSTTOEVENTBUS = _descriptor.Descriptor(
  name='RequestPostToEventBus',
  full_name='dialog.RequestPostToEventBus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestPostToEventBus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destinations', full_name='dialog.RequestPostToEventBus.destinations', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.RequestPostToEventBus.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=585,
)


_UPDATEEVENTBUSDEVICECONNECTED = _descriptor.Descriptor(
  name='UpdateEventBusDeviceConnected',
  full_name='dialog.UpdateEventBusDeviceConnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusDeviceConnected.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateEventBusDeviceConnected.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.UpdateEventBusDeviceConnected.device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateEventBusDeviceConnected.peer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=755,
)


_UPDATEEVENTBUSDEVICEDISCONNECTED = _descriptor.Descriptor(
  name='UpdateEventBusDeviceDisconnected',
  full_name='dialog.UpdateEventBusDeviceDisconnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusDeviceDisconnected.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UpdateEventBusDeviceDisconnected.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='dialog.UpdateEventBusDeviceDisconnected.device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateEventBusDeviceDisconnected.peer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=928,
)


_UPDATEEVENTBUSMESSAGE = _descriptor.Descriptor(
  name='UpdateEventBusMessage',
  full_name='dialog.UpdateEventBusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusMessage.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='dialog.UpdateEventBusMessage.sender_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_device_id', full_name='dialog.UpdateEventBusMessage.sender_device_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.UpdateEventBusMessage.message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006hidden', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=1087,
)


_UPDATEEVENTBUSDISPOSED = _descriptor.Descriptor(
  name='UpdateEventBusDisposed',
  full_name='dialog.UpdateEventBusDisposed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.UpdateEventBusDisposed.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1140,
)

_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['peer'].message_type = peers__pb2._PEER
DESCRIPTOR.message_types_by_name['RequestJoinEventBus'] = _REQUESTJOINEVENTBUS
DESCRIPTOR.message_types_by_name['ResponseJoinEventBus'] = _RESPONSEJOINEVENTBUS
DESCRIPTOR.message_types_by_name['RequestKeepAliveEventBus'] = _REQUESTKEEPALIVEEVENTBUS
DESCRIPTOR.message_types_by_name['RequestPostToEventBus'] = _REQUESTPOSTTOEVENTBUS
DESCRIPTOR.message_types_by_name['UpdateEventBusDeviceConnected'] = _UPDATEEVENTBUSDEVICECONNECTED
DESCRIPTOR.message_types_by_name['UpdateEventBusDeviceDisconnected'] = _UPDATEEVENTBUSDEVICEDISCONNECTED
DESCRIPTOR.message_types_by_name['UpdateEventBusMessage'] = _UPDATEEVENTBUSMESSAGE
DESCRIPTOR.message_types_by_name['UpdateEventBusDisposed'] = _UPDATEEVENTBUSDISPOSED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestJoinEventBus = _reflection.GeneratedProtocolMessageType('RequestJoinEventBus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTJOINEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinEventBus)
  })
_sym_db.RegisterMessage(RequestJoinEventBus)

ResponseJoinEventBus = _reflection.GeneratedProtocolMessageType('ResponseJoinEventBus', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEJOINEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseJoinEventBus)
  })
_sym_db.RegisterMessage(ResponseJoinEventBus)

RequestKeepAliveEventBus = _reflection.GeneratedProtocolMessageType('RequestKeepAliveEventBus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTKEEPALIVEEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestKeepAliveEventBus)
  })
_sym_db.RegisterMessage(RequestKeepAliveEventBus)

RequestPostToEventBus = _reflection.GeneratedProtocolMessageType('RequestPostToEventBus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTPOSTTOEVENTBUS,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestPostToEventBus)
  })
_sym_db.RegisterMessage(RequestPostToEventBus)

UpdateEventBusDeviceConnected = _reflection.GeneratedProtocolMessageType('UpdateEventBusDeviceConnected', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSDEVICECONNECTED,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusDeviceConnected)
  })
_sym_db.RegisterMessage(UpdateEventBusDeviceConnected)

UpdateEventBusDeviceDisconnected = _reflection.GeneratedProtocolMessageType('UpdateEventBusDeviceDisconnected', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSDEVICEDISCONNECTED,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusDeviceDisconnected)
  })
_sym_db.RegisterMessage(UpdateEventBusDeviceDisconnected)

UpdateEventBusMessage = _reflection.GeneratedProtocolMessageType('UpdateEventBusMessage', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSMESSAGE,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusMessage)
  })
_sym_db.RegisterMessage(UpdateEventBusMessage)

UpdateEventBusDisposed = _reflection.GeneratedProtocolMessageType('UpdateEventBusDisposed', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTBUSDISPOSED,
  '__module__' : 'event_bus_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateEventBusDisposed)
  })
_sym_db.RegisterMessage(UpdateEventBusDisposed)


DESCRIPTOR._options = None
_REQUESTJOINEVENTBUS.fields_by_name['id']._options = None
_REQUESTJOINEVENTBUS.fields_by_name['timeout']._options = None
_REQUESTJOINEVENTBUS._options = None
_RESPONSEJOINEVENTBUS._options = None
_REQUESTKEEPALIVEEVENTBUS.fields_by_name['id']._options = None
_REQUESTKEEPALIVEEVENTBUS.fields_by_name['timeout']._options = None
_REQUESTKEEPALIVEEVENTBUS._options = None
_REQUESTPOSTTOEVENTBUS.fields_by_name['id']._options = None
_REQUESTPOSTTOEVENTBUS.fields_by_name['destinations']._options = None
_REQUESTPOSTTOEVENTBUS.fields_by_name['message']._options = None
_REQUESTPOSTTOEVENTBUS._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['id']._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['user_id']._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['device_id']._options = None
_UPDATEEVENTBUSDEVICECONNECTED.fields_by_name['peer']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['id']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['user_id']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['device_id']._options = None
_UPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['peer']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['id']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['sender_id']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['sender_device_id']._options = None
_UPDATEEVENTBUSMESSAGE.fields_by_name['message']._options = None
_UPDATEEVENTBUSDISPOSED.fields_by_name['id']._options = None

_EVENTBUS = _descriptor.ServiceDescriptor(
  name='EventBus',
  full_name='dialog.EventBus',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1143,
  serialized_end=1512,
  methods=[
  _descriptor.MethodDescriptor(
    name='JoinEventBus',
    full_name='dialog.EventBus.JoinEventBus',
    index=0,
    containing_service=None,
    input_type=_REQUESTJOINEVENTBUS,
    output_type=_RESPONSEJOINEVENTBUS,
    serialized_options=b'\202\323\344\223\002#\"\036/v1/grpc/EventBus/JoinEventBus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KeepAliveEventBus',
    full_name='dialog.EventBus.KeepAliveEventBus',
    index=1,
    containing_service=None,
    input_type=_REQUESTKEEPALIVEEVENTBUS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002(\"#/v1/grpc/EventBus/KeepAliveEventBus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PostToEventBus',
    full_name='dialog.EventBus.PostToEventBus',
    index=2,
    containing_service=None,
    input_type=_REQUESTPOSTTOEVENTBUS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002%\" /v1/grpc/EventBus/PostToEventBus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTBUS)

DESCRIPTOR.services_by_name['EventBus'] = _EVENTBUS

# @@protoc_insertion_point(module_scope)
