# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import push_pb2 as push__pb2


class PushStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterGooglePush = channel.unary_unary(
                '/dialog.Push/RegisterGooglePush',
                request_serializer=push__pb2.RequestRegisterGooglePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterGooglePush = channel.unary_unary(
                '/dialog.Push/UnregisterGooglePush',
                request_serializer=push__pb2.RequestUnregisterGooglePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterApplePush = channel.unary_unary(
                '/dialog.Push/RegisterApplePush',
                request_serializer=push__pb2.RequestRegisterApplePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterApplePush = channel.unary_unary(
                '/dialog.Push/UnregisterApplePush',
                request_serializer=push__pb2.RequestUnregisterApplePush.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterApplePushKit = channel.unary_unary(
                '/dialog.Push/RegisterApplePushKit',
                request_serializer=push__pb2.RequestRegisterApplePushKit.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterApplePushKit = channel.unary_unary(
                '/dialog.Push/UnregisterApplePushKit',
                request_serializer=push__pb2.RequestUnregisterApplePushKit.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterApplePushToken = channel.unary_unary(
                '/dialog.Push/RegisterApplePushToken',
                request_serializer=push__pb2.RequestRegisterApplePushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterApplePushToken = channel.unary_unary(
                '/dialog.Push/UnregisterApplePushToken',
                request_serializer=push__pb2.RequestUnregisterApplePushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RegisterAvroraPushToken = channel.unary_unary(
                '/dialog.Push/RegisterAvroraPushToken',
                request_serializer=push__pb2.RequestRegisterAvroraPushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.UnregisterAvroraPushToken = channel.unary_unary(
                '/dialog.Push/UnregisterAvroraPushToken',
                request_serializer=push__pb2.RequestUnregisterAvroraPushToken.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class PushServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterGooglePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterGooglePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApplePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterApplePush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApplePushKit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterApplePushKit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApplePushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterApplePushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterAvroraPushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterAvroraPushToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PushServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterGooglePush': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterGooglePush,
                    request_deserializer=push__pb2.RequestRegisterGooglePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterGooglePush': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterGooglePush,
                    request_deserializer=push__pb2.RequestUnregisterGooglePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterApplePush': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApplePush,
                    request_deserializer=push__pb2.RequestRegisterApplePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterApplePush': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterApplePush,
                    request_deserializer=push__pb2.RequestUnregisterApplePush.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterApplePushKit': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApplePushKit,
                    request_deserializer=push__pb2.RequestRegisterApplePushKit.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterApplePushKit': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterApplePushKit,
                    request_deserializer=push__pb2.RequestUnregisterApplePushKit.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterApplePushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApplePushToken,
                    request_deserializer=push__pb2.RequestRegisterApplePushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterApplePushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterApplePushToken,
                    request_deserializer=push__pb2.RequestUnregisterApplePushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RegisterAvroraPushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterAvroraPushToken,
                    request_deserializer=push__pb2.RequestRegisterAvroraPushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'UnregisterAvroraPushToken': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterAvroraPushToken,
                    request_deserializer=push__pb2.RequestUnregisterAvroraPushToken.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Push', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Push(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterGooglePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterGooglePush',
            push__pb2.RequestRegisterGooglePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterGooglePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterGooglePush',
            push__pb2.RequestUnregisterGooglePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterApplePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterApplePush',
            push__pb2.RequestRegisterApplePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterApplePush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterApplePush',
            push__pb2.RequestUnregisterApplePush.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterApplePushKit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterApplePushKit',
            push__pb2.RequestRegisterApplePushKit.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterApplePushKit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterApplePushKit',
            push__pb2.RequestUnregisterApplePushKit.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterApplePushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterApplePushToken',
            push__pb2.RequestRegisterApplePushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterApplePushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterApplePushToken',
            push__pb2.RequestUnregisterApplePushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterAvroraPushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/RegisterAvroraPushToken',
            push__pb2.RequestRegisterAvroraPushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterAvroraPushToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Push/UnregisterAvroraPushToken',
            push__pb2.RequestUnregisterAvroraPushToken.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
