# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: definitions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='definitions.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x64\x65\x66initions.proto\x12\x06\x64ialog\x1a\x15scalapb/scalapb.proto\x1a google/protobuf/descriptor.proto\"%\n\tUUIDValue\x12\x0b\n\x03msb\x18\x01 \x01(\x03\x12\x0b\n\x03lsb\x18\x02 \x01(\x03\".\n\rDialogOptions\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x10\n\x08required\x18\x02 \x01(\x08\"\x1a\n\tDataClock\x12\r\n\x05\x63lock\x18\x01 \x01(\x03:C\n\x03\x64lg\x12\x1d.google.protobuf.FieldOptions\x18\xa1\x8d\x06 \x01(\x0b\x32\x15.dialog.DialogOptionsB\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


DLG_FIELD_NUMBER = 100001
dlg = _descriptor.FieldDescriptor(
  name='dlg', full_name='dialog.dlg', index=0,
  number=100001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_UUIDVALUE = _descriptor.Descriptor(
  name='UUIDValue',
  full_name='dialog.UUIDValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msb', full_name='dialog.UUIDValue.msb', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lsb', full_name='dialog.UUIDValue.lsb', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=123,
)


_DIALOGOPTIONS = _descriptor.Descriptor(
  name='DialogOptions',
  full_name='dialog.DialogOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='dialog.DialogOptions.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='dialog.DialogOptions.required', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=171,
)


_DATACLOCK = _descriptor.Descriptor(
  name='DataClock',
  full_name='dialog.DataClock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.DataClock.clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=199,
)

DESCRIPTOR.message_types_by_name['UUIDValue'] = _UUIDVALUE
DESCRIPTOR.message_types_by_name['DialogOptions'] = _DIALOGOPTIONS
DESCRIPTOR.message_types_by_name['DataClock'] = _DATACLOCK
DESCRIPTOR.extensions_by_name['dlg'] = dlg
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UUIDValue = _reflection.GeneratedProtocolMessageType('UUIDValue', (_message.Message,), {
  'DESCRIPTOR' : _UUIDVALUE,
  '__module__' : 'definitions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UUIDValue)
  })
_sym_db.RegisterMessage(UUIDValue)

DialogOptions = _reflection.GeneratedProtocolMessageType('DialogOptions', (_message.Message,), {
  'DESCRIPTOR' : _DIALOGOPTIONS,
  '__module__' : 'definitions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DialogOptions)
  })
_sym_db.RegisterMessage(DialogOptions)

DataClock = _reflection.GeneratedProtocolMessageType('DataClock', (_message.Message,), {
  'DESCRIPTOR' : _DATACLOCK,
  '__module__' : 'definitions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DataClock)
  })
_sym_db.RegisterMessage(DataClock)

dlg.message_type = _DIALOGOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(dlg)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
