# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clickroad.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='clickroad.proto',
  package='clickroad',
  syntax='proto3',
  serialized_options=b'Z\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x63lickroad.proto\x12\tclickroad\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"u\n\x0cTrackContext\x12\x35\n\x07\x63ontext\x18\x01 \x03(\x0b\x32$.clickroad.TrackContext.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x0fTrackScreenView\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x06source\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03url\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x88\x01\n\nTrackEvent\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12+\n\x05label\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"l\n\x0bTrackTiming\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\x12+\n\x05label\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\">\n\x0bTrackSocial\x12\x0f\n\x07network\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\",\n\nTrackError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\r\n\x05\x66\x61tal\x18\x02 \x01(\x08\"\xde\x02\n\x0bTrackMetric\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x17.clickroad.TrackContextH\x00\x12\x31\n\x0bscreen_view\x18\x03 \x01(\x0b\x32\x1a.clickroad.TrackScreenViewH\x00\x12&\n\x05\x65vent\x18\x04 \x01(\x0b\x32\x15.clickroad.TrackEventH\x00\x12(\n\x06timing\x18\x05 \x01(\x0b\x32\x16.clickroad.TrackTimingH\x00\x12(\n\x06social\x18\x06 \x01(\x0b\x32\x16.clickroad.TrackSocialH\x00\x12&\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x15.clickroad.TrackErrorH\x00\x12\x18\n\x10\x64\x65\x64uplication_id\x18\x08 \x01(\x03\x42\x08\n\x06metric\"I\n\x11RequestTrackEvent\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\'\n\x07metrics\x18\x02 \x03(\x0b\x32\x16.clickroad.TrackMetric\"!\n\x12ResponseTrackEvent\x12\x0b\n\x03\x63id\x18\x01 \x01(\t2X\n\tClickRoad\x12K\n\nTrackEvent\x12\x1c.clickroad.RequestTrackEvent\x1a\x1d.clickroad.ResponseTrackEvent\"\x00\x42\x08Z\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TRACKCONTEXT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='clickroad.TrackContext.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='clickroad.TrackContext.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clickroad.TrackContext.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=212,
)

_TRACKCONTEXT = _descriptor.Descriptor(
  name='TrackContext',
  full_name='clickroad.TrackContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='context', full_name='clickroad.TrackContext.context', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRACKCONTEXT_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=212,
)


_TRACKSCREENVIEW = _descriptor.Descriptor(
  name='TrackScreenView',
  full_name='clickroad.TrackScreenView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='clickroad.TrackScreenView.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='clickroad.TrackScreenView.source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='clickroad.TrackScreenView.url', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=334,
)


_TRACKEVENT = _descriptor.Descriptor(
  name='TrackEvent',
  full_name='clickroad.TrackEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='clickroad.TrackEvent.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='clickroad.TrackEvent.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='clickroad.TrackEvent.label', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clickroad.TrackEvent.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=473,
)


_TRACKTIMING = _descriptor.Descriptor(
  name='TrackTiming',
  full_name='clickroad.TrackTiming',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='clickroad.TrackTiming.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='clickroad.TrackTiming.variable', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='clickroad.TrackTiming.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='clickroad.TrackTiming.label', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=583,
)


_TRACKSOCIAL = _descriptor.Descriptor(
  name='TrackSocial',
  full_name='clickroad.TrackSocial',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='clickroad.TrackSocial.network', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='clickroad.TrackSocial.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='clickroad.TrackSocial.target', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=647,
)


_TRACKERROR = _descriptor.Descriptor(
  name='TrackError',
  full_name='clickroad.TrackError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='clickroad.TrackError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fatal', full_name='clickroad.TrackError.fatal', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=693,
)


_TRACKMETRIC = _descriptor.Descriptor(
  name='TrackMetric',
  full_name='clickroad.TrackMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='clickroad.TrackMetric.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='clickroad.TrackMetric.context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_view', full_name='clickroad.TrackMetric.screen_view', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='clickroad.TrackMetric.event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timing', full_name='clickroad.TrackMetric.timing', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='social', full_name='clickroad.TrackMetric.social', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='clickroad.TrackMetric.error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_id', full_name='clickroad.TrackMetric.deduplication_id', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='metric', full_name='clickroad.TrackMetric.metric',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=696,
  serialized_end=1046,
)


_REQUESTTRACKEVENT = _descriptor.Descriptor(
  name='RequestTrackEvent',
  full_name='clickroad.RequestTrackEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='clickroad.RequestTrackEvent.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='clickroad.RequestTrackEvent.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1121,
)


_RESPONSETRACKEVENT = _descriptor.Descriptor(
  name='ResponseTrackEvent',
  full_name='clickroad.ResponseTrackEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='clickroad.ResponseTrackEvent.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1156,
)

_TRACKCONTEXT_CONTEXTENTRY.containing_type = _TRACKCONTEXT
_TRACKCONTEXT.fields_by_name['context'].message_type = _TRACKCONTEXT_CONTEXTENTRY
_TRACKSCREENVIEW.fields_by_name['source'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKSCREENVIEW.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKEVENT.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKEVENT.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TRACKTIMING.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKMETRIC.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACKMETRIC.fields_by_name['context'].message_type = _TRACKCONTEXT
_TRACKMETRIC.fields_by_name['screen_view'].message_type = _TRACKSCREENVIEW
_TRACKMETRIC.fields_by_name['event'].message_type = _TRACKEVENT
_TRACKMETRIC.fields_by_name['timing'].message_type = _TRACKTIMING
_TRACKMETRIC.fields_by_name['social'].message_type = _TRACKSOCIAL
_TRACKMETRIC.fields_by_name['error'].message_type = _TRACKERROR
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['context'])
_TRACKMETRIC.fields_by_name['context'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['screen_view'])
_TRACKMETRIC.fields_by_name['screen_view'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['event'])
_TRACKMETRIC.fields_by_name['event'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['timing'])
_TRACKMETRIC.fields_by_name['timing'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['social'])
_TRACKMETRIC.fields_by_name['social'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['error'])
_TRACKMETRIC.fields_by_name['error'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_REQUESTTRACKEVENT.fields_by_name['metrics'].message_type = _TRACKMETRIC
DESCRIPTOR.message_types_by_name['TrackContext'] = _TRACKCONTEXT
DESCRIPTOR.message_types_by_name['TrackScreenView'] = _TRACKSCREENVIEW
DESCRIPTOR.message_types_by_name['TrackEvent'] = _TRACKEVENT
DESCRIPTOR.message_types_by_name['TrackTiming'] = _TRACKTIMING
DESCRIPTOR.message_types_by_name['TrackSocial'] = _TRACKSOCIAL
DESCRIPTOR.message_types_by_name['TrackError'] = _TRACKERROR
DESCRIPTOR.message_types_by_name['TrackMetric'] = _TRACKMETRIC
DESCRIPTOR.message_types_by_name['RequestTrackEvent'] = _REQUESTTRACKEVENT
DESCRIPTOR.message_types_by_name['ResponseTrackEvent'] = _RESPONSETRACKEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackContext = _reflection.GeneratedProtocolMessageType('TrackContext', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRACKCONTEXT_CONTEXTENTRY,
    '__module__' : 'clickroad_pb2'
    # @@protoc_insertion_point(class_scope:clickroad.TrackContext.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _TRACKCONTEXT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackContext)
  })
_sym_db.RegisterMessage(TrackContext)
_sym_db.RegisterMessage(TrackContext.ContextEntry)

TrackScreenView = _reflection.GeneratedProtocolMessageType('TrackScreenView', (_message.Message,), {
  'DESCRIPTOR' : _TRACKSCREENVIEW,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackScreenView)
  })
_sym_db.RegisterMessage(TrackScreenView)

TrackEvent = _reflection.GeneratedProtocolMessageType('TrackEvent', (_message.Message,), {
  'DESCRIPTOR' : _TRACKEVENT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackEvent)
  })
_sym_db.RegisterMessage(TrackEvent)

TrackTiming = _reflection.GeneratedProtocolMessageType('TrackTiming', (_message.Message,), {
  'DESCRIPTOR' : _TRACKTIMING,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackTiming)
  })
_sym_db.RegisterMessage(TrackTiming)

TrackSocial = _reflection.GeneratedProtocolMessageType('TrackSocial', (_message.Message,), {
  'DESCRIPTOR' : _TRACKSOCIAL,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackSocial)
  })
_sym_db.RegisterMessage(TrackSocial)

TrackError = _reflection.GeneratedProtocolMessageType('TrackError', (_message.Message,), {
  'DESCRIPTOR' : _TRACKERROR,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackError)
  })
_sym_db.RegisterMessage(TrackError)

TrackMetric = _reflection.GeneratedProtocolMessageType('TrackMetric', (_message.Message,), {
  'DESCRIPTOR' : _TRACKMETRIC,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackMetric)
  })
_sym_db.RegisterMessage(TrackMetric)

RequestTrackEvent = _reflection.GeneratedProtocolMessageType('RequestTrackEvent', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTTRACKEVENT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.RequestTrackEvent)
  })
_sym_db.RegisterMessage(RequestTrackEvent)

ResponseTrackEvent = _reflection.GeneratedProtocolMessageType('ResponseTrackEvent', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSETRACKEVENT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.ResponseTrackEvent)
  })
_sym_db.RegisterMessage(ResponseTrackEvent)


DESCRIPTOR._options = None
_TRACKCONTEXT_CONTEXTENTRY._options = None

_CLICKROAD = _descriptor.ServiceDescriptor(
  name='ClickRoad',
  full_name='clickroad.ClickRoad',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1158,
  serialized_end=1246,
  methods=[
  _descriptor.MethodDescriptor(
    name='TrackEvent',
    full_name='clickroad.ClickRoad.TrackEvent',
    index=0,
    containing_service=None,
    input_type=_REQUESTTRACKEVENT,
    output_type=_RESPONSETRACKEVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLICKROAD)

DESCRIPTOR.services_by_name['ClickRoad'] = _CLICKROAD

# @@protoc_insertion_point(module_scope)
