# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permissions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import definitions_pb2 as definitions__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='permissions.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11permissions.proto\x12\x06\x64ialog\x1a\x11\x64\x65\x66initions.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x15scalapb/scalapb.proto\"\x17\n\x15RequestGetPermissions\"\xb0\x01\n\x16ResponseGetPermissions\x12\x36\n\x0bpermissions\x18\x01 \x03(\x0e\x32\x12.dialog.PermissionB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x15\x61ll_known_permissions\x18\x02 \x03(\x0e\x32\x12.dialog.PermissionB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"o\n\x17UpdatePermissionsChange\x12\x36\n\x0bpermissions\x18\x01 \x03(\x0e\x32\x12.dialog.PermissionB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible*v\n\nPermission\x12\x16\n\x12PERMISSION_UNKNOWN\x10\x00\x12\x15\n\x11PERMISSION_SEARCH\x10\x01\x12\x1c\n\x18PERMISSION_CREATE_GROUPS\x10\x02\x12\x1b\n\x17PERMISSION_LEAVE_GROUPS\x10\x03\x32\x8e\x01\n\x0bPermissions\x12\x7f\n\x0eGetPermissions\x12\x1d.dialog.RequestGetPermissions\x1a\x1e.dialog.ResponseGetPermissions\".\x82\xd3\xe4\x93\x02(\"#/v1/grpc/Permissions/GetPermissions:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[definitions__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_PERMISSION = _descriptor.EnumDescriptor(
  name='Permission',
  full_name='dialog.Permission',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_SEARCH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_CREATE_GROUPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_LEAVE_GROUPS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=418,
  serialized_end=536,
)
_sym_db.RegisterEnumDescriptor(_PERMISSION)

Permission = enum_type_wrapper.EnumTypeWrapper(_PERMISSION)
PERMISSION_UNKNOWN = 0
PERMISSION_SEARCH = 1
PERMISSION_CREATE_GROUPS = 2
PERMISSION_LEAVE_GROUPS = 3



_REQUESTGETPERMISSIONS = _descriptor.Descriptor(
  name='RequestGetPermissions',
  full_name='dialog.RequestGetPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=124,
)


_RESPONSEGETPERMISSIONS = _descriptor.Descriptor(
  name='ResponseGetPermissions',
  full_name='dialog.ResponseGetPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.ResponseGetPermissions.permissions', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all_known_permissions', full_name='dialog.ResponseGetPermissions.all_known_permissions', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.ResponseGetPermissions.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=303,
)


_UPDATEPERMISSIONSCHANGE = _descriptor.Descriptor(
  name='UpdatePermissionsChange',
  full_name='dialog.UpdatePermissionsChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.UpdatePermissionsChange.permissions', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.UpdatePermissionsChange.clock', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=416,
)

_RESPONSEGETPERMISSIONS.fields_by_name['permissions'].enum_type = _PERMISSION
_RESPONSEGETPERMISSIONS.fields_by_name['all_known_permissions'].enum_type = _PERMISSION
_UPDATEPERMISSIONSCHANGE.fields_by_name['permissions'].enum_type = _PERMISSION
DESCRIPTOR.message_types_by_name['RequestGetPermissions'] = _REQUESTGETPERMISSIONS
DESCRIPTOR.message_types_by_name['ResponseGetPermissions'] = _RESPONSEGETPERMISSIONS
DESCRIPTOR.message_types_by_name['UpdatePermissionsChange'] = _UPDATEPERMISSIONSCHANGE
DESCRIPTOR.enum_types_by_name['Permission'] = _PERMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestGetPermissions = _reflection.GeneratedProtocolMessageType('RequestGetPermissions', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETPERMISSIONS,
  '__module__' : 'permissions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetPermissions)
  })
_sym_db.RegisterMessage(RequestGetPermissions)

ResponseGetPermissions = _reflection.GeneratedProtocolMessageType('ResponseGetPermissions', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETPERMISSIONS,
  '__module__' : 'permissions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetPermissions)
  })
_sym_db.RegisterMessage(ResponseGetPermissions)

UpdatePermissionsChange = _reflection.GeneratedProtocolMessageType('UpdatePermissionsChange', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPERMISSIONSCHANGE,
  '__module__' : 'permissions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdatePermissionsChange)
  })
_sym_db.RegisterMessage(UpdatePermissionsChange)


DESCRIPTOR._options = None
_RESPONSEGETPERMISSIONS.fields_by_name['permissions']._options = None
_RESPONSEGETPERMISSIONS.fields_by_name['all_known_permissions']._options = None
_RESPONSEGETPERMISSIONS.fields_by_name['clock']._options = None
_UPDATEPERMISSIONSCHANGE.fields_by_name['permissions']._options = None
_UPDATEPERMISSIONSCHANGE.fields_by_name['clock']._options = None

_PERMISSIONS = _descriptor.ServiceDescriptor(
  name='Permissions',
  full_name='dialog.Permissions',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=539,
  serialized_end=681,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetPermissions',
    full_name='dialog.Permissions.GetPermissions',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETPERMISSIONS,
    output_type=_RESPONSEGETPERMISSIONS,
    serialized_options=b'\202\323\344\223\002(\"#/v1/grpc/Permissions/GetPermissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PERMISSIONS)

DESCRIPTOR.services_by_name['Permissions'] = _PERMISSIONS

# @@protoc_insertion_point(module_scope)
