# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import device_info_pb2 as device__info__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class DeviceInfoStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NotifyAboutDeviceInfo = channel.unary_unary(
                '/dialog.DeviceInfo/NotifyAboutDeviceInfo',
                request_serializer=device__info__pb2.RequestNotifyAboutDeviceInfo.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class DeviceInfoServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NotifyAboutDeviceInfo(self, request, context):
        """/ Set info about current device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceInfoServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NotifyAboutDeviceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.NotifyAboutDeviceInfo,
                    request_deserializer=device__info__pb2.RequestNotifyAboutDeviceInfo.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.DeviceInfo', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeviceInfo(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NotifyAboutDeviceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.DeviceInfo/NotifyAboutDeviceInfo',
            device__info__pb2.RequestNotifyAboutDeviceInfo.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
